Skip to contents

Distribution function

Usage

Distribution_LB(data, var, split = FALSE, split_rule = NULL)

Arguments

data

a dataframe

var

variable

split

does the variable need to be splitted

split_rule

the splitting rule

Value

a plot with the variable

Examples

Distribution_LB(data = mtcars, var = "mpg", split = TRUE, split_rule = 23)
#> Loading required package: ggplot2
#> Warning: `aes_string()` was deprecated in ggplot2 3.0.0.
#>  Please use tidy evaluation idioms with `aes()`.
#>  See also `vignette("ggplot2-in-packages")` for more information.
#>  The deprecated feature was likely used in the LandS package.
#>   Please report the issue to the authors.
#> Warning: The `size` argument of `element_rect()` is deprecated as of ggplot2 3.4.0.
#>  Please use the `linewidth` argument instead.
#>  The deprecated feature was likely used in the LandS package.
#>   Please report the issue to the authors.