Function to build, starting from a dataset, the descriptive statistics of every variable
LL_Descrittive.RdFunction to build, starting from a dataset, the descriptive statistics of every variable
LL_Descrittive.RdFunction to build, starting from a dataset, the descriptive statistics of every variable