Distribution function
Distribution_LB.RdDistribution function
Examples
Distribution_LB(data = mtcars, var = "mpg", split = TRUE, split_rule = 23)
#> Loading required package: ggplot2
#> Warning: `aes_string()` was deprecated in ggplot2 3.0.0.
#> ℹ Please use tidy evaluation idioms with `aes()`.
#> ℹ See also `vignette("ggplot2-in-packages")` for more information.
#> ℹ The deprecated feature was likely used in the LandS package.
#> Please report the issue to the authors.
#> Warning: The `size` argument of `element_rect()` is deprecated as of ggplot2 3.4.0.
#> ℹ Please use the `linewidth` argument instead.
#> ℹ The deprecated feature was likely used in the LandS package.
#> Please report the issue to the authors.